import { select, csv, 
        scaleLinear, 
        extent,
        axisBottom, axisLeft,
        format
       } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const radius = 15;
  const yValue = d => d.horsepower;
  const yAxisLabel = 'Horsepower';
  const xValue = d => d.acceleration;
  const xAxisLabel = 'acceleration';
  const margin = {top: 40, right: 20, left: 90, bottom: 60};
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();;
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const xAxisG = g.append('g')
    .attr('transform', `translate(0, ${innerHeight})`)
  .call(xAxis);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(15);
  
  const yAxisG = g.append('g').call(yAxis);
  
  xAxisG.select('.domain')
  	.remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth /2)
  	.attr('y', 60)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  yAxisG.select('.domain')
  	.remove();;
  
  yAxisG.append('text')
  	.attr('fill', 'black')
  	.attr('y', -70)
  	.attr('transform', 'rotate(-90)')
  	.attr('x', -innerHeight/2)
  	.attr('text-anchor','middle')
  	.text(yAxisLabel);
  
  g.selectAll('circle').data(data)
  .enter().append('circle')
  	.attr('cx', d => xScale(xValue(d)))
  	.attr('r', radius )
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('fill', 'steelblue')
  	.on('click', d => {console.log(d);});
  
  g.append('text')
  	.attr('y', -10)
  	.text('this is a title');
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv', 
   (d) => {
  	return Object.assign(d, {
      acceleration: +d.acceleration,
      cylinders: +d.cylinders,
      displacement: +d.displacement,
      horsepower: +d.horsepower,
      mpg: +d.mpg,
      weight: +d.weight,
      year: +d.year
    })
	}).then(data => {
  console.log(data);
  render(data);
});